/**
 * @file
 * Provides javascript functionality for image library widget.
 */

(function ($, Drupal) {

  /**
   * Allows to select a pre-uploaded image using an image library browser.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches site-wide featured behaviors.
   */
  Drupal.behaviors.imageLibraryWidget = {
    attach: function (context) {
      $('.js-image-library-widget-view a.js-image-library-widget-link')
        .once('imageLibraryWidget')
        .click(function (event) {
          // Inhibit the default behavior when clicking the link.
          event.preventDefault();

          // Retrieve the image file ID.
          // @todo Get the image file ID from a data attribute in #3104544.
          // @see https://www.drupal.org/project/image_library_widget/issues/3104544
          let imageFileId = $.grep($(this).attr('class').split(/\s+/), function (c) {
            return c.match(/^image\-\d+$/);
          })[0].substring(6);

          // Get the sub-widget wrapper.
          let imageLibraryBrowser =  $(this).closest('.js-image-library-widget');
          // Retrieve the field name.
          let fieldName = imageLibraryBrowser.attr('data-drupal-field');
          // Get the image widget element.
          let widgetElement = imageLibraryBrowser.siblings('.image-widget');

          // Using 0 delta as we're only supporting single value image fields.
          // @todo Support multi-value image fields in #3103574.
          // @see https://www.drupal.org/project/image_library_widget/issues/3103574
          let delta = 0;

          // Set the pre-uploaded image ID.
          let hiddenInput = widgetElement.find('input[type="hidden"][name="' + fieldName + '[' + delta + '][fids]"]');
          hiddenInput.attr('value', imageFileId);

          // Trigger the upload button to refresh the image preview.
          let uploadButton = widgetElement.find('input[type="submit"][name="' + fieldName + '_' + delta + '_upload_button"]');
          uploadButton.trigger('mousedown');
        }
      );
    }
  };
}) (jQuery, Drupal);
